@@ -1,15 +1,17 @@
+mod edit;
 mod html;
 mod parse;
 mod query;
-mod trim;
+mod data;
 
 use std::collections::HashMap;
 
+pub use edit::Editable;
 pub use html::Htmlifiable;
 pub use parse::parse;
 pub use query::{Queryable, Selector};
-pub use trim::Trimable;
 
+/// Basic node of dom
 #[derive(Debug, Clone)]
 pub enum Node {
     Element {
@@ -23,6 +25,7 @@ pub enum Node {
 }
 
 impl Node {
+    /// Check if it is a element node.
     pub fn is_element(&self) -> bool {
         match self {
             Node::Element { .. } => true,
@@ -34,6 +37,7 @@ impl Node {
         self.clone().try_into_element()
     }
 
+    /// Try to convert the node into an element.
     pub fn try_into_element(self) -> Result<Element, &'static str> {
         match self {
             Node::Element {
@@ -50,6 +54,7 @@ impl Node {
     }
 }
 
+/// HTML Element
 #[derive(Debug)]
 pub struct Element {
     pub name: String,
